==> PyMassSpec-2.2.21-py3-none-any.whl: pyms/__init__.py <==
"""
The root of the package pyms
"""

################################################################################
#                                                                              #
#    PyMassSpec software for processing of mass-spectrometry data              #
#    Copyright (C) 2005-2012 Vladimir Likic                                    #
#    Copyright (C) 2019-2020 Dominic Davis-Foster                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License version 2 as         #
#    published by the Free Software Foundation.                                #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; if not, write to the Free Software               #
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                 #
#                                                                              #
################################################################################


#from pyms import Baseline, Deconvolution, Display, Experiment, Gapfill, GCMS, Noise, Peak, Simulator, Utils

name = "PyMassSpec"
__author__ = 'See AUTHORS'
__license__ = 'GPL v2'
__maintainer_email__ = 'dominic@davis-foster.co.uk'
__url__ = 'http://domdfcoding.github.io/PyMassSpec'
__version__ = '2.2.21'

__copyright__ = "2005-2012 Vladimir Likic, 2019-2020 Dominic Davis-Foster"
__email__ = "dominic@davis-foster.co.uk"

==> PyMassSpec-2.4.1-py3-none-any.whl: pyms/__init__.py <==
"""
The root of the package pyms.
"""

################################################################################
#                                                                              #
#    PyMassSpec software for processing of mass-spectrometry data              #
#    Copyright (C) 2005-2012 Vladimir Likic                                    #
#    Copyright (C) 2019-2020 Dominic Davis-Foster                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License version 2 as         #
#    published by the Free Software Foundation.                                #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; if not, write to the Free Software               #
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                 #
#                                                                              #
################################################################################

# from pyms import Baseline, Deconvolution, Display, Experiment, Gapfill, GCMS, Noise, Peak, Simulator, Utils

name = "PyMassSpec"
__author__ = "See AUTHORS"
__license__ = "GPLv2"
__maintainer_email__ = "dominic@davis-foster.co.uk"
__url__ = "http://domdfcoding.github.io/PyMassSpec"
__version__ = "2.2.22.b2"

__copyright__ = "2005-2012 Vladimir Likic, 2019-2020 Dominic Davis-Foster"
__email__ = "dominic@davis-foster.co.uk"
